/* QDCHKPWD - Quick and Dirty CHecK for PassWorDs
 *
 * Copyright (C) 2002 G-N-U GmbH - http://www.g-n-u.de
 *
 * QDCHKPWD is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published
 * by the Free Software Foundation; either version 2 of the License,
 * or (at your option) any later version.
 *
 * QDCHKPWD is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with QDCHKPWD; if not, write to the Free Software Foundation,
 * Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA
 */

#ifndef QDCHKPWD_H
#define QDCHKPWD_H

extern double qdchkpwd (const char *pwd);

#endif /* QDCHKPWD_H */
