/* gpawindowkeeper.h  -  The GNU Privacy Assistant
 *      Copyright (C) 2000 G-N-U GmbH.
 *
 * This file is part of GPA
 *
 * GPA is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * GPA is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA
 */

#ifndef GPAWINDOWKEEPER_H
#define GPAWINDOWKEEPER_H

#include <glib.h>
#include <gtk/gtk.h>

typedef struct
{
  GtkWidget *window;
  GList *listParam;
}
GpaWindowKeeper;

extern GpaWindowKeeper *gpa_windowKeeper_new (void);
extern void gpa_windowKeeper_set_window (GpaWindowKeeper * keeper,
					 GtkWidget * window);
extern void gpa_windowKeeper_add_param (GpaWindowKeeper * keeper,
					gpointer param);
extern void gpa_windowKeeper_release (GpaWindowKeeper * keeper);

#endif /*GPAWINDOWKEEPER*/
