/* helpmenu.h - The GNU Privacy Assistant.
   Copyright (C) 2000, 2001 G-N-U GmbH.

   This file is part of GPA.

   GPA is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 3 of the License, or
   (at your option) any later version.

   GPA is distributed in the hope that it will be useful, but WITHOUT
   ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
   or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public
   License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, see <http://www.gnu.org/licenses/>.  */

#ifndef HELPMENU_H__
#define HELPMENU_H__

#include <gtk/gtk.h>

/* Display the about dialog.  */
void gpa_help_about(GSimpleAction *simple, GVariant *parameter, gpointer user_data);

static const GActionEntry gpa_help_menu_g_action_entries[] =
  {
    { "help", NULL },
#if 0
    { "help_contents", gpa_help_contents, NULL, NULL, NULL, { 0, 0, 0 } },
#endif
    { "help_about", gpa_help_about, NULL, NULL, NULL, { 0, 0, 0 } },
  };


#endif /* HELPMENU_H__ */
